Tutorials
=========

After reading the `basic usage <../usage>`_, a good place to get a feel for how
``edges-analysis`` works is by following some tutorials.

.. toctree::
   :maxdepth: 2

   demos/processing_bowman2018
   demos/rfi_algorithm_exploration

If you've covered the tutorials and still have questions about "how to do stuff" in
``edges-analysis``, consult the FAQs:

.. toctree::
   :maxdepth: 2

   faqs/misc
